@@ -17,7 +17,7 @@ class ScrumProject(Entity):
 
     scope = Column(Text(), nullable=True)
 
-    index = Column(String(50))
+    index = Column(String(200), nullable=False)
     
     organization = relationship("Organization", back_populates="scrum_project")
     scrum_process = relationship("ScrumProcess", back_populates="scrum_project", uselist=False)
